@@ -775,7 +775,12 @@ class StructureManager:
         if self.has_charges:
             print("Total charge {:6.3f}".format(self.total_charge))
 
-    def save_structure(self, output_pdb_path: str, mod_id: str = None, rename_terms: bool = False, output_format='pdb'):
+    def save_structure(
+            self, 
+            output_pdb_path: str, 
+            mod_id: str = None, 
+            rename_terms: bool = False, 
+            output_format='pdb'):
         """
         Saves structure on disk in PDB format
 
@@ -827,25 +832,52 @@ class StructureManager:
         return mu.get_altloc_residues(self.st)
 
 # Methods to modify structure
-    def select_model(self, keep_model: int) -> None:
-        """ Selects one model and delete the others from the structure. Model is
-            renumbered to model 1
+    def select_model(self, keep_model: str) -> None:
+        """ Selects model(s) and delete the others from the structure. Model are
+            renumbered
 
             Args:
-                keep_model: Model number to keep
+                keep_model: Model number(s) to keep
         """
-        ids = [nmodel.id for nmodel in self.st.get_models()]
-        for ind, model_id in enumerate(ids):
-            if ind != keep_model - 1:
-                self.st.detach_child(model_id)
-        if keep_model != 1:
-            self.st[keep_model-1].id = 0
-        self.nmodels = 1
-        self.models_type = 0
+        models = []
+        if '-' in keep_model:
+            m1, m2 = keep_model.split('-')
+            for v in range(int(m1), int(m2) + 1):
+                models.append(v)
+        elif ',' in keep_model:
+            models = [int(m) for m in keep_model.split(',')]
+        else:
+            models = [int(keep_model)]
+        
+        ids = [mod.id for mod in self.st.get_models()]
+        for md_id in ids:
+            if self.st[md_id].serial_num not in models:
+                self.st.detach_child(md_id)
+
+        # renumbering models
+        for i, mod in enumerate(self.st):
+            mod.id = i
+            mod.serial_num = i + 1
+        
+        self.nmodels = len(self.st)
+        self.models_type = mu.guess_models_type(self.st) if self.nmodels > 1 else 0
+        
         # Update internal data
         self.update_internals()
         self.modified = True
 
+    def superimpose_models(self):
+        spimp = Superimposer()
+        if self.nmodels > 1:
+            fix_atoms = [at for at in self.st[0].get_atoms() if at.id == 'CA']
+            for mod in self.st.get_models():
+                if mod.id == 0:
+                    continue
+                mov_atoms = [at for at in self.st[mod.id].get_atoms() if at.id == 'CA']
+                spimp.set_atoms(fix_atoms, mov_atoms)
+                spimp.apply(self.st[mod.id].get_atoms())
+            self.models_type = mu.guess_models_type(self.st) if self.nmodels > 1 else 0
+            self.modified = True
     def has_models(self) -> bool:
         """ Shotcut method to check whether the structure has more than one model
 
@@ -853,6 +885,7 @@ class StructureManager:
         """
         return self.nmodels > 1
 
+
     def has_superimp_models(self) -> bool:
         """ Shotcut method to check whether the structure has superimposed
             models (i.e. NMR or ensemble)
